> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #Noise Click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example on PIC
```
#include <stdint.h>
#include "noise_hw.h"

sbit NOISE_CS      at LATE0_bit;
sbit NOISE_CS_DIR  at TRISE0_bit;
sbit NOISE_INT     at RB0_bit;
sbit NOISE_INT_DIR at TRISB0_bit;

void system_setup( void )
{
    //GPIOs
    NOISE_CS_DIR = 0;
    NOISE_INT_DIR = 1;

    //UART
    UART1_Init( 9600 );
    Delay_ms(100);
    UART1_Write_Text( "UART Initialized\r\n" );

    //SPI
    SPI1_Init_Advanced( _SPI_MASTER_OSC_DIV4, _SPI_DATA_SAMPLE_MIDDLE,
                    _SPI_CLK_IDLE_LOW, _SPI_LOW_2_HIGH );
    Delay_ms(200);
    UART1_Write_Text( "SPI Initialized\r\n" );

    //ADC
    ADC_Init();
    Delay_ms(200);
    UART1_Write_Text( "ADC Initialized\r\n" );

    //Noise Click
    noise_init();
    UART1_Write_Text( "Noise Click Initialized\r\n" );

}

```

```
void main()
{
    //Local Decalartions
    uint8_t buffer[20] = { 0 };
    uint32_t value = 0;
    uint16_t threshold = 300;

    //Setup
    system_setup();

    noise_set_threshold( threshold );

    //Loop
    while(1)
    {
        value = ADC_Read( 4 );
        LongToStr( value, buffer );
        UART1_Write_Text( buffer );
        UART1_Write_Text( "\r\n" );
        Delay_ms(20);
        if( NOISE_INT == 0 );  // Do nothing
        else
            UART1_Write_Text( "Interrupt!!!!!!\r\n" );
    }

}

```

